<?php
/**
 * The header for our theme
 *
 * @subpackage Electrician Services
 * @since 1.0
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php
	if ( function_exists( 'wp_body_open' ) ) {
	    wp_body_open();
	} else {
	    do_action( 'wp_body_open' );
	}
?>
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'electrician-services' ); ?></a>
	<?php if( get_theme_mod('electrician_services_theme_loader','') != ''){ ?>
		<div class="preloader">
			<div class="load">
			  <hr/><hr/><hr/><hr/>
			</div>
		</div>
	<?php }?>
	<div id="page" class="site">
		<div class="wrap_figure text-md-left text-center py-2">
			<div class="container">
				<div class="row">
					<div class="col-lg-5 col-md-5 col-sm-5 align-self-center py-2">
						<div class="row">
							<div class="col-lg-6 col-md-6 col-sm-6 align-self-center">
								<?php if( get_theme_mod('electrician_services_timing_text') != '' || get_theme_mod('electrician_services_timing_open_time') != ''){ ?>
									<div class="row">
										<div class="col-lg-3 col-md-3 col-sm-3 align-self-center">
											<i class="far fa-clock"></i>
										</div>
										<div class="col-lg-9 col-md-9 col-sm-9 align-self-center">
											<h6 class="mb-0"><?php echo esc_html(get_theme_mod('electrician_services_timing_text','')); ?></h6>
											<p class="mb-0"><?php echo esc_html(get_theme_mod('electrician_services_timing_open_time','')); ?></p>
										</div>
									</div>
								<?php }?>
							</div>
							<div class="col-lg-6 col-md-6 col-sm-6 align-self-center">
								<?php if( get_theme_mod('electrician_services_location_text') != '' || get_theme_mod('electrician_services_location_address') != ''){ ?>
									<div class="row">
										<div class="col-lg-2 col-md-2 col-sm-2 align-self-center">
											<i class="fas fa-map-marker-alt"></i>
										</div>
										<div class="col-lg-10 col-md-10 col-sm-10 align-self-center">
											<h6 class="mb-0"><?php echo esc_html(get_theme_mod('electrician_services_location_text','')); ?></h6>
											<p class="mb-0"><?php echo esc_html(get_theme_mod('electrician_services_location_address','')); ?></p>
										</div>
									</div>
								<?php }?>
							</div>
						</div>
					</div>
					<div class="col-lg-2 col-md-2 col-sm-2 mb-2 mb-md-0">
						<div class="logo py-3 py-lg-0">
					        <?php if ( has_custom_logo() ) : ?>
			            		<?php the_custom_logo(); ?>
				            <?php endif; ?>
			              	<?php $electrician_services_blog_info = get_bloginfo( 'name' ); ?>
				                <?php if ( ! empty( $electrician_services_blog_info ) ) : ?>
				                  	<?php if ( is_front_page() && is_home() ) : ?>
				                    	<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				                  	<?php else : ?>
			                      		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
			                  		<?php endif; ?>
				                <?php endif; ?>
				                <?php
			                  		$electrician_services_description = get_bloginfo( 'description', 'display' );
				                  	if ( $electrician_services_description || is_customize_preview() ) :
				                ?>
				                <p class="site-description mb-0"><?php echo esc_html($electrician_services_description); ?></p>
			              	<?php endif; ?>
					    </div>
					</div>
					<div class="col-lg-5 col-md-5 col-sm-5 align-self-center py-2">
						<div class="row">
							<div class="col-lg-5 col-md-5 col-sm-5 align-self-center">
								<?php if( get_theme_mod('electrician_services_call_text') != '' || get_theme_mod('electrician_services_call_phone_number') != ''){ ?>
									<div class="row">
										<div class="col-lg-3 col-md-3 col-sm-3 align-self-center">
											<i class="fas fa-phone"></i>
										</div>
										<div class="col-lg-9 col-md-9 col-sm-9 align-self-center">
											<h6 class="mb-0"><?php echo esc_html(get_theme_mod('electrician_services_call_text','')); ?></h6>
											<p class="mb-0"><?php echo esc_html(get_theme_mod('electrician_services_call_phone_number','')); ?></p>
										</div>
									</div>
								<?php }?>
							</div>
							<div class="col-lg-7 col-md-7 col-sm-7 align-self-center">
								<?php if( get_theme_mod('electrician_services_mail_text') != '' || get_theme_mod('electrician_services_mail_email_address') != ''){ ?>
									<div class="row">
										<div class="col-lg-2 col-md-2 col-sm-2 align-self-center">
											<i class="far fa-envelope"></i>
										</div>
										<div class="col-lg-10 col-md-10 col-sm-10 align-self-center">
											<h6 class="mb-0"><?php echo esc_html(get_theme_mod('electrician_services_mail_text','')); ?></h6>
											<p class="mb-0"><?php echo esc_html(get_theme_mod('electrician_services_mail_email_address','')); ?></p>
										</div>
									</div>
								<?php }?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<div class="menu-header">
			<div class="container">
				<div class="menu-header-inner mx-3 mx-md-5">
					<div class="row">
						<div class="col-lg-9 col-md-6 col-sm-6 col-3 p-0 align-self-center">
							<?php if(has_nav_menu('primary')){?>
								<div class="toggle-menu gb_menu text-md-left">
									<button onclick="electrician_services_gb_Menu_open()" class="gb_toggle p-2"><i class="fas fa-ellipsis-h"></i><p class="mb-0"><?php esc_html_e('Menu','electrician-services'); ?></p></button>
								</div>
							<?php }?>
							<?php get_template_part('template-parts/navigation/navigation'); ?>
						</div>
						<div class="col-lg-3 col-md-6 col-sm-6 col-9 align-self-center">
		                  	<div class="linksbox text-md-right text-center">
								<?php if( get_theme_mod('electrician_services_facebook') != ''){ ?>
									<a href="<?php echo esc_url(get_theme_mod('electrician_services_facebook','')); ?>"><i class="fab fa-facebook-f mr-2"></i></a>
								<?php }?>
								<?php if( get_theme_mod('electrician_services_twitter') != ''){ ?>
									<a href="<?php echo esc_url(get_theme_mod('electrician_services_twitter','')); ?>"><i class="fab fa-twitter mr-2"></i></a>
								<?php }?>
								<?php if( get_theme_mod('electrician_services_linkdin') != ''){ ?>
									<a href="<?php echo esc_url(get_theme_mod('electrician_services_linkdin','')); ?>"><i class="fab fa-linkedin-in mr-2"></i></a>
								<?php }?>
								<?php if( get_theme_mod('electrician_services_youtube') != ''){ ?>
									<a href="<?php echo esc_url(get_theme_mod('electrician_services_youtube','')); ?>"><i class="fab fa-youtube mr-2"></i></a>
								<?php }?>
								<?php if( get_theme_mod('electrician_services_instagram') != ''){ ?>
									<a href="<?php echo esc_url(get_theme_mod('electrician_services_instagram','')); ?>"><i class="fab fa-instagram mr-2"></i></a>
								<?php }?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
