<?php
/**
 * Electrician Services: Customizer
 *
 * @subpackage Electrician Services
 * @since 1.0
 */

function electrician_services_customize_register( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_template_directory_uri() ). '/assets/css/customizer.css');

	// Add custom control.
  	require get_parent_theme_file_path( 'inc/customize/customize_toggle.php' );

	// Register the custom control type.
	$wp_customize->register_control_type( 'Electrician_Services_Toggle_Control' );

 	$wp_customize->add_section('electrician_services_pro', array(
        'title'    => __('UPGRADE ELECTRICIAN PREMIUM', 'electrician-services'),
        'priority' => 1,
    ));
    $wp_customize->add_setting('electrician_services_pro', array(
        'default'           => null,
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control(new Electrician_Services_Pro_Control($wp_customize, 'electrician_services_pro', array(
        'label'    => __('ELECTRICIAN SERVICES PREMIUM', 'electrician-services'),
        'section'  => 'electrician_services_pro',
        'settings' => 'electrician_services_pro',
        'priority' => 1,
    )));

	// Theme General Settings
    $wp_customize->add_section('electrician_services_theme_settings',array(
        'title' => __('Theme General Settings', 'electrician-services'),
        'priority' => 1,
    ) );

    $wp_customize->add_setting( 'electrician_services_theme_loader', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'electrician_services_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Electrician_Services_Toggle_Control( $wp_customize, 'electrician_services_theme_loader', array(
		'label'       => esc_html__( 'Show Site Loader', 'electrician-services' ),
		'section'     => 'electrician_services_theme_settings',
		'type'        => 'toggle',
		'settings'    => 'electrician_services_theme_loader',
	) ) );

	$wp_customize->add_setting( 'electrician_services_scroll_enable', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'electrician_services_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Electrician_Services_Toggle_Control( $wp_customize, 'electrician_services_scroll_enable', array(
		'label'       => esc_html__( 'Show Scroll Top', 'electrician-services' ),
		'section'     => 'electrician_services_theme_settings',
		'type'        => 'toggle',
		'settings'    => 'electrician_services_scroll_enable',
	) ) );

	// Post Layouts
    $wp_customize->add_section('electrician_services_layout',array(
        'title' => __('Post Layout', 'electrician-services'),
        'description' => __( 'Change the post layout from below options', 'electrician-services' ),
        'priority' => 1
    ) );

	$wp_customize->add_setting( 'electrician_services_post_sidebar', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'electrician_services_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Electrician_Services_Toggle_Control( $wp_customize, 'electrician_services_post_sidebar', array(
		'label'       => esc_html__( 'Show Fullwidth', 'electrician-services' ),
		'section'     => 'electrician_services_layout',
		'type'        => 'toggle',
		'settings'    => 'electrician_services_post_sidebar',
	) ) );

	$wp_customize->add_setting( 'electrician_services_single_post_sidebar', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'electrician_services_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Electrician_Services_Toggle_Control( $wp_customize, 'electrician_services_single_post_sidebar', array(
		'label'       => esc_html__( 'Show Single Post Fullwidth', 'electrician-services' ),
		'section'     => 'electrician_services_layout',
		'type'        => 'toggle',
		'settings'    => 'electrician_services_single_post_sidebar',
	) ) );

    $wp_customize->add_setting('electrician_services_post_option',array(
		'default' => 'simple_post',
		'sanitize_callback' => 'electrician_services_sanitize_select'
	));
	$wp_customize->add_control('electrician_services_post_option',array(
		'label' => esc_html__('Select Layout','electrician-services'),
		'section' => 'electrician_services_layout',
		'setting' => 'electrician_services_post_option',
		'type' => 'radio',
        'choices' => array(
            'simple_post' => __('Simple Post','electrician-services'),
            'grid_post' => __('Grid Post','electrician-services'),
        ),
	));

    $wp_customize->add_setting('electrician_services_grid_column',array(
		'default' => '3_column',
		'sanitize_callback' => 'electrician_services_sanitize_select'
	));
	$wp_customize->add_control('electrician_services_grid_column',array(
		'label' => esc_html__('Grid Post Per Row','electrician-services'),
		'section' => 'electrician_services_layout',
		'setting' => 'electrician_services_grid_column',
		'type' => 'radio',
        'choices' => array(
            '1_column' => __('1','electrician-services'),
            '2_column' => __('2','electrician-services'),
            '3_column' => __('3','electrician-services'),
            '4_column' => __('4','electrician-services'),
            '5_column' => __('6','electrician-services'),
        ),
	));

	$wp_customize->add_setting( 'electrician_services_date', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'electrician_services_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Electrician_Services_Toggle_Control( $wp_customize, 'electrician_services_date', array(
		'label'       => esc_html__( 'Hide Date', 'electrician-services' ),
		'section'     => 'electrician_services_layout',
		'type'        => 'toggle',
		'settings'    => 'electrician_services_date',
	) ) );

	$wp_customize->add_setting( 'electrician_services_admin', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'electrician_services_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Electrician_Services_Toggle_Control( $wp_customize, 'electrician_services_admin', array(
		'label'       => esc_html__( 'Hide Author/Admin', 'electrician-services' ),
		'section'     => 'electrician_services_layout',
		'type'        => 'toggle',
		'settings'    => 'electrician_services_admin',
	) ) );

	$wp_customize->add_setting( 'electrician_services_comment', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'electrician_services_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Electrician_Services_Toggle_Control( $wp_customize, 'electrician_services_comment', array(
		'label'       => esc_html__( 'Hide Comment', 'electrician-services' ),
		'section'     => 'electrician_services_layout',
		'type'        => 'toggle',
		'settings'    => 'electrician_services_comment',
	) ) );

	// Header
    $wp_customize->add_section('electrician_services_header',array(
        'title' => __('Header', 'electrician-services'),
        'description' => __( 'Add header information in the below feilds', 'electrician-services' ),
        'priority' => 3
    ) );

	$wp_customize->add_setting('electrician_services_call_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_call_text',array(
		'label' => esc_html__('Call Text','electrician-services'),
		'section' => 'electrician_services_header',
		'setting' => 'electrician_services_call_text',
		'type'    => 'text'
	));

	$wp_customize->add_setting('electrician_services_call_phone_number',array(
		'default' => '',
		'sanitize_callback' => 'electrician_services_sanitize_phone_number'
	));
	$wp_customize->add_control('electrician_services_call_phone_number',array(
		'label' => esc_html__('Phone Number','electrician-services'),
		'section' => 'electrician_services_header',
		'setting' => 'electrician_services_call_phone_number',
		'type'    => 'text'
	));

	$wp_customize->add_setting('electrician_services_mail_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_mail_text',array(
		'label' => esc_html__('Email Text','electrician-services'),
		'section' => 'electrician_services_header',
		'setting' => 'electrician_services_mail_text',
		'type'    => 'text'
	));

	$wp_customize->add_setting('electrician_services_mail_email_address',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_email'
	));
	$wp_customize->add_control('electrician_services_mail_email_address',array(
		'label' => esc_html__('Email Address','electrician-services'),
		'section' => 'electrician_services_header',
		'setting' => 'electrician_services_mail_email_address',
		'type'    => 'text'
	));

	$wp_customize->add_setting('electrician_services_location_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_location_text',array(
		'label' => esc_html__('Location Text','electrician-services'),
		'section' => 'electrician_services_header',
		'setting' => 'electrician_services_location_text',
		'type'    => 'text'
	));

	$wp_customize->add_setting('electrician_services_location_address',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_location_address',array(
		'label' => esc_html__('Location Adreess','electrician-services'),
		'section' => 'electrician_services_header',
		'setting' => 'electrician_services_location_address',
		'type'    => 'text'
	));

	$wp_customize->add_setting('electrician_services_timing_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_timing_text',array(
		'label' => esc_html__('Timing Text','electrician-services'),
		'section' => 'electrician_services_header',
		'setting' => 'electrician_services_timing_text',
		'type'    => 'text'
	));

	$wp_customize->add_setting('electrician_services_timing_open_time',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_timing_open_time',array(
		'label' => esc_html__('Opening Timing','electrician-services'),
		'section' => 'electrician_services_header',
		'setting' => 'electrician_services_timing_open_time',
		'type'    => 'text'
	));

		// Social Media
    $wp_customize->add_section('electrician_services_urls',array(
        'title' => __('Social Media', 'electrician-services'),
        'description' => __( 'Add social media links in the below feilds', 'electrician-services' ),
        'priority' => 3
    ) );

	$wp_customize->add_setting('electrician_services_facebook',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('electrician_services_facebook',array(
		'label' => esc_html__('Facebook URL','electrician-services'),
		'section' => 'electrician_services_urls',
		'setting' => 'electrician_services_facebook',
		'type'    => 'url'
	));

	$wp_customize->add_setting('electrician_services_twitter',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('electrician_services_twitter',array(
		'label' => esc_html__('Twitter URL','electrician-services'),
		'section' => 'electrician_services_urls',
		'setting' => 'electrician_services_twitter',
		'type'    => 'url'
	));

	$wp_customize->add_setting('electrician_services_linkdin',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('electrician_services_linkdin',array(
		'label' => esc_html__('Linkedin URL','electrician-services'),
		'section' => 'electrician_services_urls',
		'setting' => 'electrician_services_linkdin',
		'type'    => 'url'
	));

	$wp_customize->add_setting('electrician_services_youtube',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('electrician_services_youtube',array(
		'label' => esc_html__('Youtube URL','electrician-services'),
		'section' => 'electrician_services_urls',
		'setting' => 'electrician_services_youtube',
		'type'    => 'url'
	));

	$wp_customize->add_setting('electrician_services_instagram',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('electrician_services_instagram',array(
		'label' => esc_html__('Instagram URL','electrician-services'),
		'section' => 'electrician_services_urls',
		'setting' => 'electrician_services_instagram',
		'type'    => 'url'
	));

    //Slider
	$wp_customize->add_section( 'electrician_services_slider_section' , array(
    	'title'      => __( 'Slider Settings', 'electrician-services' ),
    	'description' => __('Slider Image Dimension ( 1600px x 650px )','electrician-services'),
		'priority'   => 3,
	) );

	$wp_customize->add_setting('electrician_services_slide_heading',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_slide_heading',array(
		'label' => esc_html__('Slider Text','electrician-services'),
		'section' => 'electrician_services_slider_section',
		'setting' => 'electrician_services_slide_heading',
		'type'    => 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_post[]= 'select';
	foreach($categories as $category){
	if($i==0){
	  $default = $category->slug;
	  $i++;
	}
	$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('electrician_services_post_setting',array(
		'default' => 'select',
		'sanitize_callback' => 'electrician_services_sanitize_select',
	));
	$wp_customize->add_control('electrician_services_post_setting',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => esc_html__('Select Category to display slider images','electrician-services'),
		'section' => 'electrician_services_slider_section',
	));

	// Project Section
	$wp_customize->add_section( 'electrician_services_project_section' , array(
    	'title'      => __( 'Project Section Settings', 'electrician-services' ),
		'priority'   => 4,
	) );

    $wp_customize->add_setting('electrician_services_project_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_project_text',array(
		'label'	=> esc_html__('Add Short Heading','electrician-services'),
		'section'	=> 'electrician_services_project_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('electrician_services_project_heading',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_project_heading',array(
		'label'	=> esc_html__('Add Heading','electrician-services'),
		'section'	=> 'electrician_services_project_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('electrician_services_project_btn_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('electrician_services_project_btn_url',array(
		'label'	=> esc_html__('Add Button Url','electrician-services'),
		'section'	=> 'electrician_services_project_section',
		'type'		=> 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_post[]= 'select';
	foreach($categories as $category){
	if($i==0){
	  $default = $category->slug;
	  $i++;
	}
	$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('electrician_services_project_setting',array(
		'default' => 'select',
		'sanitize_callback' => 'electrician_services_sanitize_select',
	));
	$wp_customize->add_control('electrician_services_project_setting',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => esc_html__('Select Category to display projects','electrician-services'),
		'section' => 'electrician_services_project_section',
	));

	//Footer
    $wp_customize->add_section( 'electrician_services_footer_copyright', array(
    	'title' => esc_html__( 'Footer Text', 'electrician-services' ),
    	'priority' => 6
	) );

    $wp_customize->add_setting('electrician_services_footer_text',array(
			'default'	=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
	));
		$wp_customize->add_control('electrician_services_footer_text',array(
			'label'	=> esc_html__('Copyright Text','electrician-services'),
			'section'	=> 'electrician_services_footer_copyright',
			'type'		=> 'text'
	));

	$wp_customize->add_setting('electrician_services_footer_widget',array(
		'default' => '4',
		'sanitize_callback' => 'electrician_services_sanitize_select'
	));
	$wp_customize->add_control('electrician_services_footer_widget',array(
		'label' => esc_html__('Footer Per Column','electrician-services'),
		'section' => 'electrician_services_footer_copyright',
		'setting' => 'electrician_services_footer_widget',
		'type' => 'radio',
		'choices' => array(
			'1'   => __('1 Column', 'electrician-services'),
			'2'  => __('2 Column', 'electrician-services'),
			'3' => __('3 Column', 'electrician-services'),
			'4' => __('4 Column', 'electrician-services')
		),
	));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'electrician_services_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'electrician_services_customize_partial_blogdescription',
	) );

	//front page
	$num_sections = apply_filters( 'electrician_services_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		$wp_customize->add_setting( 'panel_' . $i, array(
			'default'           => false,
			'sanitize_callback' => 'electrician_services_sanitize_dropdown_pages',
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'panel_' . $i, array(
			/* translators: %d is the front page section number */
			'label'          => sprintf( __( 'Front Page Section %d Content', 'electrician-services' ), $i ),
			'description'    => ( 1 !== $i ? '' : __( 'Select pages to feature in each area from the dropdowns. Add an image to a section by setting a featured image in the page editor. Empty sections will not be displayed.', 'electrician-services' ) ),
			'section'        => 'theme_options',
			'type'           => 'dropdown-pages',
			'allow_addition' => true,
			'active_callback' => 'electrician_services_is_static_front_page',
		) );

		$wp_customize->selective_refresh->add_partial( 'panel_' . $i, array(
			'selector'            => '#panel' . $i,
			'render_callback'     => 'electrician_services_front_page_section',
			'container_inclusive' => true,
		) );
	}
}
add_action( 'customize_register', 'electrician_services_customize_register' );

function electrician_services_customize_partial_blogname() {
	bloginfo( 'name' );
}
function electrician_services_customize_partial_blogdescription() {
	bloginfo( 'description' );
}
function electrician_services_is_static_front_page() {
	return ( is_front_page() && ! is_home() );
}
function electrician_services_is_view_with_layout_option() {
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
}

define('ELECTRICIAN_SERVICES_PRO_LINK',__('https://www.ovationthemes.com/wordpress/electrical-wordpress-theme/','electrician-services'));

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('Electrician_Services_Pro_Control')):
    class Electrician_Services_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
	        <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( ELECTRICIAN_SERVICES_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE ELECTRICIAN PREMIUM','electrician-services');?> </a>
	        </div>
            <div class="col-md">
                <img class="electrician_services_img_responsive " src="<?php echo esc_url(get_template_directory_uri()); ?>/screenshot.png">
            </div>
	        <div class="col-md">
	            <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('ELECTRICIAN SERVICES PREMIUM - Features', 'electrician-services'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'electrician-services');?> </li>
                    <li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'electrician-services');?> </li>
                   	<li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'electrician-services');?> </li>
                   	<li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'electrician-services');?> </li>
                   	<li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'electrician-services');?> </li>
                   	<li class="upsell-electrician_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'electrician-services');?> </li>
                </ul>
        	</div>
		    <div class="col-md upsell-btn upsell-btn-bottom">
	            <a href="<?php echo esc_url( ELECTRICIAN_SERVICES_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE ELECTRICIAN PREMIUM','electrician-services');?> </a>
		    </div>
        </label>
    <?php } }
endif;